@@ -1,6 +1,6 @@
 /*******************************************************************
 *
-* This file is part of the KDE project "Bovo"
+* Copyright 2007  Aron Boström <c02ab@efd.lth.se>
 *
 * Bovo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 
 #include "hintitem.h"
 
-#include <QtCore/QTimer>
-#include <QtGui/QColor>
-#include <QtGui/QPainter>
-#include <QtSvg/QSvgRenderer>
+#include <QTimer>
+#include <QColor>
+#include <QPainter>
+#include <QSvgRenderer>
 
 #include "common.h"
 #include "coord.h"
